cmp

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 30, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

const (
	XGoPackage = true
)

Variables

This section is empty.

Functions

func XGot_CmpApp_Main added in v0.3.0

func XGot_CmpApp_Main(this interface{ MainEntry() })

XGot_CmpApp_Main is main entry of this classfile.

Types

type CmpApp

type CmpApp struct {
	// contains filtered or unexported fields
}

func (*CmpApp) CompareVer

func (app *CmpApp) CompareVer(fn func(a, b module.Version) int)

The provided function fn will be used to compare version strings when resolving dependencies for those versions which are not in Debian-style.

Jump to