modules

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 30, 2026 License: Apache-2.0 Imports: 27 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Module

type Module struct {
	*formula.Formula

	FS      fs.FS
	Path    string
	Version string

	// Deps holds direct dependencies only (not transitive).
	// For the main module, Deps contains all modules in the build list.
	// For non-main modules, Deps contains only the declared dependencies
	// from versions.json. The build module can reconstruct the full
	// dependency graph from these adjacency edges.
	Deps []*Module
}

Module represents a loaded module with its formula, filesystem, and resolved dependencies.

func Load

func Load(ctx context.Context, main module.Version, opts Options) ([]*Module, error)

Load loads all packages required by the main module and resolves their dependencies using the MVS algorithm. It returns modules for all packages in the computed build list.

type Options

type Options struct {
	// FormulaStore is the store for downloading and caching formulas.
	FormulaStore repo.Store
	Matrix       classfile.Matrix
}

Options contains options for Load.

Directories

Path Synopsis
Package modlocal resolves local filesystem patterns into module paths and their corresponding directories.
Package modlocal resolves local filesystem patterns into module paths and their corresponding directories.

Jump to