module

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 30, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package module defines the module.Version type along with support code.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EscapePath

func EscapePath(path string) (escaped string, err error)

EscapePath returns the escaped form of the given module path as a valid file system path. It fails if the module path is invalid.

Types

type Version

type Version struct {
	Path    string // Module path in the form "owner/repo"
	Version string // Version string (e.g., "1.0.0")
}

A Version (for clients, a module.Version) represents a specific version of a module identified by its path.

Jump to