cmp

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 14, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

const GopPackage = true

Variables

This section is empty.

Functions

func Gopt_CmpApp_Main

func Gopt_CmpApp_Main(this interface{ MainEntry() })

Gopt_CmpApp_Main is main entry of this classfile.

Types

type CmpApp

type CmpApp struct {
	// contains filtered or unexported fields
}

func (*CmpApp) CompareVer

func (f *CmpApp) CompareVer(fn func(a, b module.Version) int)

The provided function fn will be used to compare version strings when resolving dependencies for those versions which are not in Debian-style.

Jump to