Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Module ¶
type Module struct {
*formula.Formula
FS fs.FS
Path string
Version string
// Deps holds direct dependencies only (not transitive).
// For the main module, Deps contains all modules in the build list.
// For non-main modules, Deps contains only the declared dependencies
// from versions.json. The build module can reconstruct the full
// dependency graph from these adjacency edges.
Deps []*Module
}
Module represents a loaded module with its formula, filesystem, and resolved dependencies.
Click to show internal directories.
Click to hide internal directories.